# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class GenerateToolInput(UncheckedBaseModel):
    tool_name: str = pydantic.Field()
    """
    Name of the tool to generate code for
    """

    prompt: str = pydantic.Field()
    """
    User prompt to generate code
    """

    handle: typing.Optional[str] = pydantic.Field(default=None)
    """
    Handle of the tool to generate code for
    """

    starter_code: typing.Optional[str] = pydantic.Field(default=None)
    """
    Python source code to parse for JSON schema
    """

    validation_errors: typing.List[str] = pydantic.Field()
    """
    List of validation errors
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from .templates_list_response_templates_item import TemplatesListResponseTemplatesItem


class TemplatesListResponse(UncheckedBaseModel):
    templates: typing.List[TemplatesListResponseTemplatesItem]
    has_next_page: typing_extensions.Annotated[bool, FieldMetadata(alias="hasNextPage")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    AddMcpServerRequest,
    AddMcpServerResponseItem,
    ConnectMcpServerRequest,
    ConnectMcpServerResponseEvent,
    DeleteMcpServerResponseItem,
    ListMcpServersResponseValue,
    StreamingResponse,
    TestMcpServerRequest,
    UpdateMcpServerRequest,
    UpdateMcpServerResponse,
)

__all__ = [
    "AddMcpServerRequest",
    "AddMcpServerResponseItem",
    "ConnectMcpServerRequest",
    "ConnectMcpServerResponseEvent",
    "DeleteMcpServerResponseItem",
    "ListMcpServersResponseValue",
    "StreamingResponse",
    "TestMcpServerRequest",
    "UpdateMcpServerRequest",
    "UpdateMcpServerResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .identity_property_type import IdentityPropertyType
from .identity_property_value import IdentityPropertyValue


class IdentityProperty(UncheckedBaseModel):
    """
    A property of an identity
    """

    key: str = pydantic.Field()
    """
    The key of the property
    """

    value: IdentityPropertyValue = pydantic.Field()
    """
    The value of the property
    """

    type: IdentityPropertyType = pydantic.Field()
    """
    The type of the property
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
